==> davidwing-vue3lib-0.1.2.tgz: package/vue.config.js <==

// Generated using webpack-cli https://github.com/webpack/webpack-cli

const path = require("path");
const fs = require('fs')

const AutoImport = require('unplugin-auto-import/webpack')
const Components = require('unplugin-vue-components/webpack')
const { ElementPlusResolver } = require('unplugin-vue-components/resolvers')

// const HtmlWebpackPlugin = require("html-webpack-plugin");
const MiniCssExtractPlugin = require("mini-css-extract-plugin");
// const VueLoaderPlugin = require('vue-loader/lib/plugin')

const webpack = require('webpack');

const isProduction = process.env.NODE_ENV == "production";

function resolve(dir) {
  return path.join(__dirname, dir)
}

const stylesHandler = isProduction ? MiniCssExtractPlugin.loader : "style-loader";

const { defineConfig } = require('@vue/cli-service')
const vue = require('@vitejs/plugin-vue')

module.exports = defineConfig({
  runtimeCompiler: true,
  transpileDependencies: true,
  publicPath: isProduction ? './' : process.env.VUE_APP_BASE_URL, //署应用包时的基本 URL。  vue-router history模式使用
  assetsDir: 'static',
  lintOnSave: isProduction,
  productionSourceMap: true,
  outputDir: path.resolve(__dirname, './dist'),
  parallel: undefined,
  css: undefined,
  configureWebpack: {
    entry: "./examples/main.ts",
    experiments: {
      outputModule: true,
    },
    output: {
      path: isProduction ? path.resolve(__dirname, 'dist') : undefined
    },
    devServer: {
      open: false,
      hot: true,
      historyApiFallback: true,
      allowedHosts: "all",
      compress: true,
      host: "0.0.0.0",
      https: {
        cert: fs.readFileSync(path.join(__dirname, 'cert.crt')),
        key: fs.readFileSync(path.join(__dirname, 'cert.key'))
      },
      port: 2020,
      headers: {
        "Access-Control-Allow-Origin": "*", // 主应用获取子应用时跨域响应头
      },
      proxy: {
        '/H5': { //此处要与 /services/api.js 中的 API_PROXY_PREFIX 值保持一致
          target: "http://emcarosys.cn:8019",
          changeOrigin: false,
          pathRewrite: {
            '^/H5': '/H5'
          }
        }
      }
    },
    plugins: [
      AutoImport({
        resolvers: [ElementPlusResolver()],
      }),
      Components({
        resolvers: [ElementPlusResolver()],
      }),
    ]

  }
})

==> davidwing-vue3lib-0.1.6.tgz: package/vue.config.js <==

// Generated using webpack-cli https://github.com/webpack/webpack-cli

const path = require("path");
const fs = require('fs')

const AutoImport = require('unplugin-auto-import/webpack')
const Components = require('unplugin-vue-components/webpack')
const { ElementPlusResolver } = require('unplugin-vue-components/resolvers')

// const HtmlWebpackPlugin = require("html-webpack-plugin");
const MiniCssExtractPlugin = require("mini-css-extract-plugin");
// const VueLoaderPlugin = require('vue-loader/lib/plugin')

const webpack = require('webpack');

const isProduction = process.env.NODE_ENV == "production";

function resolve(dir) {
  return path.join(__dirname, dir)
}

const stylesHandler = isProduction ? MiniCssExtractPlugin.loader : "style-loader";

const { defineConfig } = require('@vue/cli-service')
const vue = require('@vitejs/plugin-vue')

module.exports = defineConfig({
  runtimeCompiler: true,
  transpileDependencies: true,
  publicPath: isProduction ? './' : process.env.VUE_APP_BASE_URL, //署应用包时的基本 URL。  vue-router history模式使用
  assetsDir: 'static',
  lintOnSave: isProduction,
  productionSourceMap: true,
  outputDir: path.resolve(__dirname, './dist'),
  parallel: undefined,
  css: undefined,
  configureWebpack: {
    entry: "./examples/main.ts",
    experiments: {
      outputModule: true,
    },
    output: {
      path: isProduction ? path.resolve(__dirname, 'dist') : undefined
    },
    devServer: {
      open: false,
      hot: true,
      historyApiFallback: true,
      allowedHosts: "all",
      compress: true,
      host: "0.0.0.0",
      https: {
        cert: fs.readFileSync(path.join(__dirname, 'cert.crt')),
        key: fs.readFileSync(path.join(__dirname, 'cert.key'))
      },
      port: 2020,
      headers: {
        "Access-Control-Allow-Origin": "*", // 主应用获取子应用时跨域响应头
      },
      proxy: {
        '/H5': { //此处要与 /services/api.js 中的 API_PROXY_PREFIX 值保持一致
          target: "http://www.emacrosys.cn:8019",
          changeOrigin: false,
          pathRewrite: {
            '^/H5': '/H5'
          }
        },
        '/EMacroApi': { //此处要与 /services/api.js 中的 API_PROXY_PREFIX 值保持一致
          target: "http://www.emacrosys.cn:8019",
          changeOrigin: false,
          pathRewrite: {
            '^/EMacroApi': '/EMacroApi'
          }
        }
      }
    },
    plugins: [
      AutoImport({
        resolvers: [ElementPlusResolver()],
      }),
      Components({
        resolvers: [ElementPlusResolver()],
      }),
    ]

  }
})
